chat

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Chat

type Chat struct {
	// Readers for files to be attached to the next message the client sends in this chat
	Attachments []io.Reader
	// Data for each message in the chat
	//  Key (int) - Message ID
	//  Val (*prot.MessageRaw) - Message data
	Messages     map[int]*prot.MessageRaw
	MessagesBind map[int]binding.String
	// Chat metadata
	Metadata   prot.ChatMetadata
	ReplyingTo []int
}

Cache and data for a chat

func NewChatCache

func NewChatCache() *Chat

type ChatCache

type ChatCache struct {
	// Cache and data for each loaded chat
	//  Key (int) - Chat ID
	//  Val (*Chat) - Chat cache and data
	Chats map[int]*Chat
	// Cache and data for chat currently shown on screen, is null if there is no chat on screen
	ThisChat *Chat
}

Jump to