Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GUI ¶
type GUI struct {
// Base container that splits the window into the sidebar and main screen
Base *container.Split
// Chat screen
Chat *schat.ScreenChat
// All dialogs used by Ping
Dialogs dialogs.DialogTable
// Manages inner windows
InnerWindows *container.MultipleWindows
// Options screen
Options *sopt.ScreenOptions
OutgoingRequests chan prot.ChatRequest
// Manages screens
ScreenManager *screen.ScreenManager
// Sidebar
Sidebar *sside.ScreenSidebar
// The main window
Window fyne.Window
}
func InitGUI ¶
func InitGUI( a fyne.App, c *chat.ChatCache, u *user.UserCache, loadingWindow fyne.Window, opt *options.Options, onQuit func(), ) *GUI
InitGUI: Initializes the main window and all objects in it, closes the loading window and then shows the main window Parameters:
a (fyne.App) - The fyne application the window will be initialized in c (*chat.ChatCache) - Data/cache for chats u (*user.UserCache) - Information pertaining to users loadingWindow (fyne.Window) - The loading window opt (*options.Options) - Options/settings onQuit (func()) - Code to run when quiting Ping (main window closed)
Returns:
*GUI - The main window and all its objects
Click to show internal directories.
Click to hide internal directories.