package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jul 29, 2026
License: AGPL-3.0
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func CreateChatRequest(chatID int, reqType prot.RequestWhat, username string, messageContent string, messageID int) []byte
StartNet: Connect to the server and show an error dialog if it fails
Parameters:
gui (*gui.GUI) - GUI elements
u (*user.UserData) - Information pertaining to users
opt (*options.Options) - Options/settings
Source Files
¶
Click to show internal directories.
Click to hide internal directories.