gui

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: AGPL-3.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GUI

type GUI struct {
	// Chat screen
	Chat *schat.ScreenChat
	// All dialogs used by Ping
	Dialogs dialogs.DialogTable
	// Manages inner windows
	InnerWindows *container.MultipleWindows
	// Options screen
	Options *sopt.ScreenOptions
	// Manages screens
	ScreenManager *screen.ScreenManager
	// The main window
	Window fyne.Window
}

func InitGUI

func InitGUI(
	a fyne.App, c *chat.ChatCache,
	u *user.UserCache, loadingWindow fyne.Window, opt *options.Options,
) *GUI

InitGUI: Initializes the main window and all objects in it, closes the loading window and then shows the main window Parameters:

	a (fyne.App) - The fyne application the window will be initialized in
 c (*chat.ChatCache) - Data/cache for chats
 u (*user.UserCache) - Information pertaining to users
	loadingWindow (fyne.Window) - The loading window
 opt (*options.Options) - Options/settings

Returns:

*GUI - The main window and all its objects

Directories

Path Synopsis

Jump to