Documentation
¶
Index ¶
Constants ¶
const S_CHAT_FLOAT = "CHAT_FLOAT"
const S_CHAT_FOCUS_DEFAULT = "CHAT_FOCUS_DEFAULT"
const S_CHAT_FULL = "CHAT_FULL"
const S_OPTIONS_FLOAT = "OPTIONS_FLOAT"
const S_OPTIONS_FULL = "OPTIONS_FULL"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ScreenManager ¶
type ScreenManager struct {
Chan chan string
}
func NewScreenManager ¶
func NewScreenManager() *ScreenManager
func (*ScreenManager) ScreenChatFocusDefault ¶ added in v0.3.0
func (s *ScreenManager) ScreenChatFocusDefault()
This should be used ONLY when the code using it does not have access to chat screen's widgets, since it is slower than just doing it directly with fyne.Window.Canvas().Focus()
func (*ScreenManager) ScreenChatFull ¶
func (s *ScreenManager) ScreenChatFull()
func (*ScreenManager) ScreenOptionsFloat ¶
func (s *ScreenManager) ScreenOptionsFloat()
Click to show internal directories.
Click to hide internal directories.